package com.amazonaws.regions;

import com.amazonaws.AmazonWebServiceClient;
import com.amazonaws.ClientConfiguration;
import com.amazonaws.auth.AWSCredentialsProvider;
import com.amazonaws.regions.RegionImpl;
import com.amazonaws.regions.RegionUtils;
import com.amazonaws.regions.Regions;
import com.amazonaws.util.ValidationUtils;
import java.lang.reflect.Constructor;
import java.util.Collection;

public class Region {

   private final RegionImpl regionImpl;


   public Region(RegionImpl regionImpl) {
      ValidationUtils.assertNotNull(regionImpl, "region implementation");
      this.regionImpl = regionImpl;
   }

   public static Region getRegion(Regions region) {
      return RegionUtils.getRegion(region.getName());
   }

   public String getName() {
      return this.regionImpl.getName();
   }

   public String getDomain() {
      return this.regionImpl.getDomain();
   }

   public String getPartition() {
      return this.regionImpl.getPartition();
   }

   public String getServiceEndpoint(String endpointPrefix) {
      return this.regionImpl.getServiceEndpoint(endpointPrefix);
   }

   public boolean isServiceSupported(String serviceName) {
      return this.regionImpl.isServiceSupported(serviceName);
   }

   public boolean hasHttpsEndpoint(String serviceName) {
      return this.regionImpl.hasHttpsEndpoint(serviceName);
   }

   public boolean hasHttpEndpoint(String serviceName) {
      return this.regionImpl.hasHttpEndpoint(serviceName);
   }

   public Collection getAvailableEndpoints() {
      return this.regionImpl.getAvailableEndpoints();
   }

   /** @deprecated */
   @Deprecated
   public AmazonWebServiceClient createClient(Class serviceClass, AWSCredentialsProvider credentials, ClientConfiguration config) {
      try {
         Constructor constructor;
         AmazonWebServiceClient client;
         if(credentials == null && config == null) {
            constructor = serviceClass.getConstructor(new Class[0]);
            client = (AmazonWebServiceClient)constructor.newInstance(new Object[0]);
         } else if(credentials == null) {
            constructor = serviceClass.getConstructor(new Class[]{ClientConfiguration.class});
            client = (AmazonWebServiceClient)constructor.newInstance(new Object[]{config});
         } else if(config == null) {
            constructor = serviceClass.getConstructor(new Class[]{AWSCredentialsProvider.class});
            client = (AmazonWebServiceClient)constructor.newInstance(new Object[]{credentials});
         } else {
            constructor = serviceClass.getConstructor(new Class[]{AWSCredentialsProvider.class, ClientConfiguration.class});
            client = (AmazonWebServiceClient)constructor.newInstance(new Object[]{credentials, config});
         }

         client.setRegion(this);
         return client;
      } catch (Exception var7) {
         throw new RuntimeException("Couldn\'t instantiate instance of " + serviceClass, var7);
      }
   }

   public boolean equals(Object obj) {
      if(!(obj instanceof Region)) {
         return false;
      } else {
         Region region = (Region)obj;
         return this.getName().equals(region.getName());
      }
   }

   public int hashCode() {
      return this.getName().hashCode();
   }

   public String toString() {
      return this.getName();
   }
}
